@@ -106,11 +106,11 @@
 #' 
 #' Gile, Krista J. and Handcock, Mark S. (2014) \pkg{sspse}: Estimating Hidden 
 #' Population Size using Respondent Driven Sampling Data
-#' R package, Los Angeles, CA.  Version 0.5, \url{https://github.com/HPMRG}.
+#' R package, Los Angeles, CA.  Version 0.5, \url{https://hpmrg.org/sspse/}.
 #' 
 #' Handcock MS (2003).  \pkg{degreenet}: Models for Skewed Count Distributions
 #' Relevant to Networks.  Statnet Project, Seattle, WA.  Version 1.2,
-#' \url{https://statnet.org}.
+#' \url{https://statnet.org/}.
 #' 
 #' Handcock, Mark S., Gile, Krista J. and Mar, Corinne M. (2014)
 #' \emph{Estimating Hidden Population Size using Respondent-Driven Sampling
@@ -394,7 +394,9 @@ dsizeprior<-function(n,
       if(is.null(maxN.set)){maxN = min(maxNmax,maxN)}
      }
      }
-     cat(sprintf("Final alpha: %f, beta = %f max=%f\n",alpha, beta, maxbeta))
+     if(verbose){
+       cat(sprintf("Final alpha: %f, beta = %f max=%f\n",alpha, beta, maxbeta))
+     }
      if(is.null(alpha)) alpha=1
      if(is.null(beta)){
        warning("No prior information about the population size was specified! Using a prior mode of twice the sample size. Please specify prior information!", call. = FALSE)
