@@ -2,47 +2,48 @@
 #define POSTERIORCMPVIS_H
 
 void gcmpvis (int *pop,
-            int *K, 
-            int *n, 
+            int *K,
+            int *n,
             int *samplesize, int *burnin, int *interval,
-            double *mu, double *dfmu, 
+            double *mu, double *dfmu,
             double *sigma, double *dfsigma,
-	    double *lnlam, double *nu,
-            double *beta0muprior, double *beta0sigmaprior, 
-            double *beta1muprior, double *beta1sigmaprior, 
+            double *lnlam, double *nu,
+            double *beta0muprior, double *beta0sigmaprior,
+            double *betatmuprior, double *betatsigmaprior,
+            double *betaumuprior, double *betausigmaprior,
             double *lmemmu, double *memdfmu,
             double *memnu, double *memdfnu,
             int *Npi,
-            int *srd, 
-            int *numrec, 
+            int *srd,
+            int *numrec,
             double *rectime,
             int *maxcoupons,
-            double *lnlamproposal, 
-            double *nuproposal, 
-            double *beta0proposal, double *beta1proposal, 
+            double *lnlamproposal,
+            double *nuproposal,
+            double *beta0proposal, double *betatproposal, double *betauproposal,
             double *lmemmuproposal, double *memnuproposal,
-            int *N, int *maxN, 
-            double *sample, 
-            int *vsample, 
-            double *posu, 
-            double *posd, 
-            double *lpriorm, 
+            int *N, int *maxN,
+            double *sample,
+            int *vsample,
+            double *posu,
+            double *posd,
+            double *lpriorm,
             int *burnintheta,
             int *burninbeta,
             int *verbose
-         );
+                         );
 
-void MHcmpmem (int *d, int *n, int *K,
-            double *beta0, double *beta0sd, double *beta1, double *beta1sd, 
+void MHcmpmem (int *u, int *n, int *K,
+            double *beta0, double *beta0sd, double *betat, double *betatsd, double *betau, double *betausd,
             double *lmemmu, double *memdfmu,
             double *memnu, double *memdfnu,
             int *srd, 
             int *numrec, 
             double *rectime,
             int *maxcoupons,
-            double *beta0proposal, double *beta1proposal, 
+            double *beta0proposal, double *betatproposal, double *betauproposal, 
             double *lmemmuproposal, double *memnuproposal, 
-            double *beta0sample, double *beta1sample,
+            double *beta0sample, double *betatsample, double *betausample,
             double *lmemmusample, double *memnusample,
             int *samplesize, int *staken, int *burnin, int *interval,
             int *verbose
